@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2008-2014 by Dominique Dumont.
+# This software is Copyright (c) 2008-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::OpenSsh::Ssh ;
-$Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.238';
+$Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.241';
 use Mouse ;
 use 5.10.1;
 extends "Config::Model::Backend::OpenSsh" ;
@@ -41,40 +41,43 @@ sub host {
 }
 
 sub forward {
-    my ($self,$root,$key,$args,$comment)  = @_;
+    my ($self, $root, $key, $args, $comment, $check)  = @_;
     $logger->debug("forward: $key @$args # $comment");
     $self->current_node = $root unless defined $self->current_node ;
 
     my $elt_name = $key =~ /local/i ? 'Localforward' : 'RemoteForward' ;
-    my $size = $self->current_node->fetch_element($key)->fetch_size;
 
     my $v6 = ($args->[1] =~ m![/\[\]]!) ? 1 : 0;
 
     $logger->info("ssh: load $key '".join("','", @$args)."' ". ( $v6 ? 'IPv6' : 'IPv4'));
 
     # cleanup possible square brackets used for IPv6
-    foreach (@$args) {s/[\[\]]+//g;}
+    foreach (@$args) {
+        s/[\[\]]+//g;
+    }
 
     # reverse enable to assign string to port even if no bind_adress
     # is specified
-    my $re = $v6 ? qr!/! : qr!:! ; 
+    my $re = $v6 ? qr!/! : qr!:! ;
     my ($port,$bind_adr ) = reverse split $re,$args->[0] ;
     my ($host,$host_port) = split $re,$args->[1] ;
 
-    my $load_str = '';
-    $load_str .= "GatewayPorts=1 " if $bind_adr ;
-    my $note = $comment || '' ;
-    $note =~ s/"/\\"/g;
-    $note = qq!#"$note"! if $note ;
-    $load_str .= "$key:$size$note ";
+    my $fw_list = $self->current_node->fetch_element($key);
+    my $size = $fw_list->fetch_size;
+    # this creates a new node in the list
+    my $fw_obj = $fw_list->fetch_with_id($size);
 
-    $load_str .= 'ipv6=1 ' if $v6 ;
+    # $fw_obj->store_element_value( GatewayPorts => 1 ) if $bind_adr ;
+    $fw_obj->annotation($comment) if $comment;
 
-    $load_str .= "bind_address=$bind_adr " if defined $bind_adr ;
-    $load_str .= "port=$port host=$host hostport=$host_port";
+    $fw_obj->store_element_value( ipv6 => 1) if $v6 ;
+
+    $fw_obj->store_element_value( check => $check, name => 'bind_address', value => $bind_adr)
+        if defined $bind_adr ;
+    $fw_obj->store_element_value( check => $check, name => 'port', value => $port );
+    $fw_obj->store_element_value( check => $check, name => 'host', value => $host );
+    $fw_obj->store_element_value( check => $check, name => 'hostport', value => $host_port );
 
-    $logger->debug("load string $load_str") ; 
-    $self->current_node -> load($load_str) ;
 }
 
 sub write_all_host_block {
@@ -85,17 +88,17 @@ sub write_all_host_block {
     my $result = '' ;
 
     foreach my $pattern ( $host_elt->fetch_all_indexes) {
-	my $block_elt = $host_elt->fetch_with_id($pattern) ;
+        my $block_elt = $host_elt->fetch_with_id($pattern) ;
         $logger->debug("write_all_host_block on ".$block_elt->location." mode $mode");
-	my $block_data = $self->write_node_content($block_elt,'custom') ;
+        my $block_data = $self->write_node_content($block_elt,'custom') ;
 
-	# write data only if custom pattern or custom data is found this
-	# is necessary to avoid writing data from /etc/ssh/ssh_config that
-	# were entered as 'preset' data
-	if ($block_data) {
-	    $result .= $self->write_line(Host => $pattern, $block_elt->annotation);
-	    $result .= "$block_data\n" ;
-	}
+        # write data only if custom pattern or custom data is found this
+        # is necessary to avoid writing data from /etc/ssh/ssh_config that
+        # were entered as 'preset' data
+        if ($block_data) {
+            $result .= $self->write_line(Host => $pattern, $block_elt->annotation);
+            $result .= "$block_data\n" ;
+        }
     }
     return $result ;
 }
@@ -112,17 +115,19 @@ sub write_forward {
 
     my $line = '';
     foreach my $name ($forward_elt->get_element_name() ) {
-	next if $name eq 'ipv6' ;
-	my $elt = $forward_elt->fetch_element($name) ;
-	my $v = $elt->fetch($mode) ;
-	next unless length($v);
-	$line .=  $name =~ /bind|host$/ ? "$v$sep"
-	       :  $name eq 'port'       ? "$v "
-	       :                           $v ;
+        next if $name eq 'ipv6' ;
+        my $elt = $forward_elt->fetch_element($name) ;
+        my $v = $elt->fetch($mode) ;
+        next unless length($v);
+        $line
+            .=  $name =~ /bind|host$/ ? "$v$sep"
+            :   $name eq 'port'       ? "$v "
+            :                            $v ;
     }
 
     return $self->write_line($forward_elt->element_name,$line,$forward_elt->annotation) ;
 }
+
 1;
 
 no Mouse;
@@ -141,7 +146,7 @@ Config::Model::Backend::OpenSsh::Ssh - Backend for ssh configuration files
 
 =head1 VERSION
 
-version 1.238
+version 1.241
 
 =head1 SYNOPSIS
 
@@ -158,19 +163,19 @@ These details are not needed for the basic usages explained in L<Config::Model::
 
 =head1 Methods
 
-These read/write functions are part of C<OpenSsh::Ssh> read/write backend. 
-They are 
-declared in Ssh configuration model and are called back when needed to read the 
+These read/write functions are part of C<OpenSsh::Ssh> read/write backend.
+They are
+declared in Ssh configuration model and are called back when needed to read the
 configuration file and write it back.
 
 =head2 read (object => <ssh_root>, config_dir => ...)
 
-Read F<ssh_config> in C<config_dir> and load the data in the 
+Read F<ssh_config> in C<config_dir> and load the data in the
 C<ssh_root> configuration tree.
 
 =head2 write (object => <ssh_root>, config_dir => ...)
 
-Write F<ssh_config> in C<config_dir> from the data stored in  
+Write F<ssh_config> in C<config_dir> from the data stored in
 C<ssh_root> configuration tree.
 
 =head1 SEE ALSO
@@ -183,7 +188,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2008-2014 by Dominique Dumont.
+This software is Copyright (c) 2008-2018 by Dominique Dumont.
 
 This is free software, licensed under:
 
